Module: Pry::Memory
- Defined in:
- lib/pry/memory.rb,
lib/pry/memory/version.rb
Defined Under Namespace
Modules: Generators, Hook, Prompt, Strategy
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
-
.start(strategy = nil, &block) ⇒ Object
Runs some patches and prepares pry for storing all evaluated variables.
-
.stop ⇒ Object
Stops all activity and restore patched configuration to its original state.
Class Method Details
.start(strategy = nil, &block) ⇒ Object
Runs some patches
and prepares pry for storing all
evaluated variables
15 16 17 18 19 |
# File 'lib/pry/memory.rb', line 15 def start(strategy = nil, &block) Strategy.configure(strategy, &block) Prompt.replace Hook.register end |
.stop ⇒ Object
Stops all activity
and restore patched configuration
to its original state
25 26 27 28 |
# File 'lib/pry/memory.rb', line 25 def stop Prompt.restore Hook.unregister end |